/*

Census Schedule-C country codes: http://www.census.gov/foreign-trade/schedules/c/country.txt

Nominal GDP from WDI: http://data.worldbank.org/indicator/NY.GDP.MKTP.CD
	http://databank.worldbank.org/data/download/WDI_csv.zip
Real GDP from PWT: http://pwt.econ.upenn.edu/Downloads/pwt71/pwt71_11302012version.zip
Real GDP per capita from PWT: http://pwt.econ.upenn.edu/Downloads/pwt71/pwt71_11302012version.zip
Distances from CEPII: http://www.cepii.fr/distance/dist_cepii.dta

*/
clear
tempfile countries

* read mapping from 2-digit to 3-digit ISO country codes
insheet using http://commondatastorage.googleapis.com/ckannet-storage/2011-11-25T132653/iso_3166_2_countries.csv, case
keep ISO316612LetterCode ISO316613LetterCode
ren ISO316612LetterCode iso2
ren ISO316613LetterCode iso3
keep if !missing(iso2)
duplicates drop
save `countries', replace

* read census numerical codes
clear
infix census_code 1-4 str country_name 15-66 str iso2 69-70 using http://www.census.gov/foreign-trade/schedules/c/country.txt in 6/246
merge 1:1 iso2 using `countries'
tab _m
drop _m
keep if !missing(iso3)
save `countries', replace

* read distance from CEPII
clear
use http://www.cepii.fr/distance/dist_cepii.dta
keep if iso_d=="USA"
keep iso_o dist
ren iso_o iso3
ren dist distance
merge 1:1 iso3 using `countries'
tab _m
drop _m
save `countries', replace

clear
insheet using ../data/gravity/pwt71_wo_country_names_wo_g_vars.csv, comma case 
ren isocode iso3
ren POP population
ren rgdpch real_gdp_per_capita
ren tcgdp real_gdp

keep if year==2005

keep iso3 population real_gdp real_gdp_per_capita
merge 1:1 iso3 using `countries'
tab _m
drop _m
save `countries', replace

clear
insheet using ../data/gravity/WDI_Data.csv, case names
ren CountryCode iso3
keep if IndicatorCode=="NY.GDP.MKTP.CD"
drop IndicatorCode
keep iso3 v50 /* 2005 data */
ren v50 nominal_gdp

merge 1:1 iso3 using `countries'
tab _m
drop _m

* merge on distances from Baldwin and Harrigan 2011
gen BH2011_distance_dummy = census_code
recode BH2011_distance_dummy 1220 2010 = 0 /*
*/3070 2740 2150 2470 2720 2230 2080 2250 2190 2410 3010 2110 2050 = 1 /*
*/4010 4330 4550 4419 3530 4710 4759 7460 3510 7500 4190 7230 4279 7210 4050 3310 4000 3350 3330 7140 7642 4210 4039 4700 4231 4370 4120 7450 7440 4099 4280 = 2 /*
*/4870 7960 7630 7490 7510 7610 7790 7520 4840 5380 7530 7550 7290 4890 7870 5820 7420 7749 7690 5110 5800 5020 7560 5350 5210 5360 5330 7780 5880 3550 7830 5081 3570 7670 7970 7890 4850 5650 7910 5070 7940 5700 7480 7600 3370 = 3 /*
*/5570 6021 7850 6141 5490 5420 5600 7880 7800 = 4 /*
*/ *=.

* create distance dummies and log variables
tab BH2011_distance_dummy, gen(dist_)
foreach X of var nominal_gdp real_gdp real_gdp_per_capita distance {
	gen ln_`X' = ln(`X') 
}

compress
keep if !missing(census_code)
save ../data/gravity/gravity_variables, replace
